Skip to contents

This generic computes entropy summaries for fixation patterns represented as fixation groups or density maps.

Usage

fixation_entropy(x, ...)

Arguments

x

The input object.

...

Additional arguments passed to methods.

Value

A numeric entropy value, or a named numeric vector for multiscale objects when requested.